==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/wavpack/translations/wavpack_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="de">
<defaultcodec></defaultcodec>
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="28"/>
        <source>WavPack Plugin</source>
        <translation>WavPack Plugin</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="30"/>
        <source>WavPackk Files</source>
        <translation type="obsolete">WavPack Dateien</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="89"/>
        <source>About WavPack Audio Plugin</source>
        <translation>Über WavPack Audio Plugin</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="90"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp WavPack Audio Plugin</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="92"/>
        <source>WavPack library version:</source>
        <translation>WavPack Version:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="93"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="30"/>
        <source>WavPack Files</source>
        <translation>WavPack Dateien</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>KBps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Dateipfad:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>WavPack Info</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>Abtastrate:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>Dateigröße:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>Bitrate:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>Verhältnis:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>APE Tag</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>Titelnummer:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>Jahr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>Künstler:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/wavpack/translations/wavpack_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>WavPack-Modul</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="129"/>
        <source>About WavPack Audio Plugin</source>
        <translation>Über WavPack-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="130"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp WavPack-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="131"/>
        <source>WavPack library version:</source>
        <translation>WavPack-Bibliotheksversion:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="133"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>WavPack-Dateien</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Dateipfad:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>WavPack-Info</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="58"/>
        <location filename="../detailsdialog.ui" line="75"/>
        <location filename="../detailsdialog.ui" line="92"/>
        <location filename="../detailsdialog.ui" line="118"/>
        <location filename="../detailsdialog.ui" line="135"/>
        <location filename="../detailsdialog.ui" line="152"/>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>Abtastrate:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>Dateigröße:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>Bitrate:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>Verhältnis:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>APE-Tag</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>Titelnummer:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>Jahr:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>Interpret:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
</TS>
